@@ -312,14 +312,18 @@ class VariableOsInstallKernelResume(ReadonlyVariable):
 
     def get(self):
         """install kernel resume parameter"""
-        for dev, install in zip(self.Get('os_install_disk_use'),
-                                self.Get('os_install_disk_mount')):
+        for dev, partuuid, install in zip(self.Get('os_install_disk_use'),
+                                          self.Get('os_install_disk_partuuid'),
+                                          self.Get('os_install_disk_mount')):
             if install == "swap":
                 if self.Get('os_install_kernel_tuxonice_set') == 'on':
                     return "tuxonice tuxonice_resume=%s real_resume=%s" % (
                         dev, dev)
                 else:
-                    return "real_resume=%s" % dev
+                    if partuuid:
+                        return "resume=PARTUUID=%s" % partuuid
+                    else:
+                        return "resume=%s" % dev
         return ""
 
 
